testGPL: A fake GPL detection

testGPLR Documentation

A fake GPL detection

Description

A manually created fake GPL contour, mimicing what the output would be from the Pamguard module and fed into the GPL calcs

Usage

data(testGPL)

Format

A list with three items:

freq

a vector of the frequency contour values in hertz

time

a vector of the time values of the contour in seconds


PAMpal documentation built on Feb. 27, 2026, 1:06 a.m.