testWhistle: A fake whistle contour

testWhistleR Documentation

A fake whistle contour

Description

A manually created fake whistle contour reanging from 1kHz to 3.1kHz

Usage

data(testWhistle)

Format

A list with two items:

freq

a vector of the frequency contour values in hertz

time

a vector of the time values of the contour in seconds


PAMpal documentation built on Feb. 27, 2026, 1:06 a.m.